darkhistory.physics.chi — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.chi

`darkhistory.physics.` `chi` = 0.07894736842105261

  Ratio of helium to hydrogen nuclei.

#### Previous topic

darkhistory.physics.nA

#### Next topic

darkhistory.physics.YHe

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.